# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`gpfs`](#gpfs): base GPFS class
* [`gpfs::ces`](#gpfsces): GPFS CES class
* [`gpfs::client`](#gpfsclient): GPFS client class
* [`gpfs::gui`](#gpfsgui): GPFS GUI class
* [`gpfs::server`](#gpfsserver): GPFS server class

#### Private Classes

* `gpfs::ces::config`: Manage GPFS CES config
* `gpfs::ces::install`: Manage GPFS CES install
* `gpfs::client::config`: Manage GPFS client config
* `gpfs::client::install`: Manage GPFS client install
* `gpfs::gui::config`: Manage GPFS GUI config
* `gpfs::gui::install`: Manage GPFS GUI install
* `gpfs::gui::service`: Manage GPFS GUI services
* `gpfs::install`: Manage GPFS installs
* `gpfs::repo`: Manage GPFS repo
* `gpfs::server::config`: Manage GPFS NSD config
* `gpfs::server::install`: Manage GPFS NSD install

### Defined types

* [`gpfs::client::rkm`](#gpfsclientrkm): Manage GPFS client ISKLM configuration

### Resource types

* [`gpfs_config`](#gpfs_config): GPFS config
* [`gpfs_fileset`](#gpfs_fileset): Manage a GPFS fileset
* [`gpfs_fileset_quota`](#gpfs_fileset_quota): Set a GPFS fileset quota
* [`scalemgmt_config`](#scalemgmt_config): scalemgmt config
* [`scalemgmt_conn_validator`](#scalemgmt_conn_validator): Verify that a connection can be successfully established between a node and the scalemgmt server.  Its primary use is as a precondition to pr

## Classes

### <a name="gpfs"></a>`gpfs`

base GPFS class

#### Examples

##### 

```puppet
include ::gpfs
```

#### Parameters

The following parameters are available in the `gpfs` class:

* [`manage_repo`](#manage_repo)
* [`repo_baseurl`](#repo_baseurl)
* [`manage_packages`](#manage_packages)
* [`package_ensure`](#package_ensure)
* [`packages`](#packages)
* [`config_filesystems`](#config_filesystems)

##### <a name="manage_repo"></a>`manage_repo`

Data type: `Boolean`

Sets if GPFS repo should be managed

Default value: ``true``

##### <a name="repo_baseurl"></a>`repo_baseurl`

Data type: `Optional[String]`

The GPFS repo baseurl

Default value: ``undef``

##### <a name="manage_packages"></a>`manage_packages`

Data type: `Boolean`

Determines if GPFS packages should be managed

Default value: ``true``

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

GPFS package ensure property

Default value: `'present'`

##### <a name="packages"></a>`packages`

Data type: `Array`

GPFS base packages

Default value: `[
    "gpfs.gplbin-${facts['kernelrelease']}",
    'gpfs.adv',
    'gpfs.base',
    'gpfs.crypto',
    'gpfs.docs',
    'gpfs.ext',
    'gpfs.gpl',
    'gpfs.gskit',
    'gpfs.msg.en_US',
  ]`

##### <a name="config_filesystems"></a>`config_filesystems`

Data type: `Optional[Array]`

Filesystems where filesets are managed by Puppet

Default value: ``undef``

### <a name="gpfsces"></a>`gpfs::ces`

GPFS CES class

#### Examples

##### 

```puppet
include ::gpfs::ces
```

#### Parameters

The following parameters are available in the `gpfs::ces` class:

* [`manage_packages`](#manage_packages)
* [`package_ensure`](#package_ensure)
* [`packages`](#packages)

##### <a name="manage_packages"></a>`manage_packages`

Data type: `Boolean`

Determines if GPFS CES packages should be managed

Default value: ``true``

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

GPFS CES package ensure property

Default value: `'present'`

##### <a name="packages"></a>`packages`

Data type: `Array`

GPFS CES packages

Default value: `[
    'gpfs.java',
    'gpfs.smb',
    'nfs-ganesha',
    'nfs-ganesha-gpfs',
    'nfs-ganesha-utils',
  ]`

### <a name="gpfsclient"></a>`gpfs::client`

GPFS client class

#### Examples

##### 

```puppet
include ::gpfs::client
```

#### Parameters

The following parameters are available in the `gpfs::client` class:

* [`manage_packages`](#manage_packages)
* [`package_ensure`](#package_ensure)
* [`packages`](#packages)
* [`manage_service_files`](#manage_service_files)
* [`manage_ssh_authorized_keys`](#manage_ssh_authorized_keys)
* [`ssh_user`](#ssh_user)
* [`ssh_authorized_keys`](#ssh_authorized_keys)
* [`rkms`](#rkms)
* [`bin_paths`](#bin_paths)

##### <a name="manage_packages"></a>`manage_packages`

Data type: `Boolean`

Determines if GPFS client packages should be managed

Default value: ``true``

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String[1]`

GPFS client package ensure property

Default value: `'present'`

##### <a name="packages"></a>`packages`

Data type: `Array[String[1]]`

GPFS client packages

Default value: `[]`

##### <a name="manage_service_files"></a>`manage_service_files`

Data type: `Boolean`

Determines if GPFS service files are managed

Default value: ``true``

##### <a name="manage_ssh_authorized_keys"></a>`manage_ssh_authorized_keys`

Data type: `Boolean`

Determines if SSH authorized_keys should be managed

Default value: ``true``

##### <a name="ssh_user"></a>`ssh_user`

Data type: `String[1]`

SSH user for GPFS

Default value: `'root'`

##### <a name="ssh_authorized_keys"></a>`ssh_authorized_keys`

Data type: `Hash`

SSH authorized keys for NSDs

Default value: `{}`

##### <a name="rkms"></a>`rkms`

Data type: `Hash`

Hash to define gpfs::client::rkm resources

Default value: `{}`

##### <a name="bin_paths"></a>`bin_paths`

Data type: `Array[Stdlib::Absolutepath]`

Paths to add to PATH

Default value: `[]`

### <a name="gpfsgui"></a>`gpfs::gui`

GPFS GUI class

#### Examples

##### 

```puppet
include ::gpfs::gui
```

#### Parameters

The following parameters are available in the `gpfs::gui` class:

* [`manage_packages`](#manage_packages)
* [`package_ensure`](#package_ensure)
* [`packages`](#packages)
* [`manage_firewall`](#manage_firewall)
* [`firewall_source`](#firewall_source)
* [`firewall_https_only`](#firewall_https_only)
* [`manage_services`](#manage_services)
* [`manage_initgui`](#manage_initgui)

##### <a name="manage_packages"></a>`manage_packages`

Data type: `Boolean`

Determines if GPFS GUI packages should be managed

Default value: ``true``

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

GPFS GUI package ensure property

Default value: `'present'`

##### <a name="packages"></a>`packages`

Data type: `Array`

GPFS GUI packages

Default value: `[
    'gpfs.gui',
  ]`

##### <a name="manage_firewall"></a>`manage_firewall`

Data type: `Boolean`

Determines if firewall should be managed

Default value: ``true``

##### <a name="firewall_source"></a>`firewall_source`

Data type: `Optional[Variant[String, Array, Boolean]]`

Firewall source value

Default value: ``undef``

##### <a name="firewall_https_only"></a>`firewall_https_only`

Data type: `Boolean`

Only manage firewall rules for HTTPS

Default value: ``false``

##### <a name="manage_services"></a>`manage_services`

Data type: `Boolean`

Determines if services are managed

Default value: ``true``

##### <a name="manage_initgui"></a>`manage_initgui`

Data type: `Boolean`

Determines if manage Exec to initialize GUI

Default value: ``true``

### <a name="gpfsserver"></a>`gpfs::server`

GPFS server class

#### Examples

##### 

```puppet
include ::gpfs::server
```

#### Parameters

The following parameters are available in the `gpfs::server` class:

* [`manage_packages`](#manage_packages)
* [`package_ensure`](#package_ensure)
* [`packages`](#packages)
* [`bin_paths`](#bin_paths)

##### <a name="manage_packages"></a>`manage_packages`

Data type: `Boolean`

Determines if GPFS server packages should be managed

Default value: ``true``

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

GPFS server package ensure property

Default value: `'present'`

##### <a name="packages"></a>`packages`

Data type: `Array`

GPFS server packages

Default value: `[]`

##### <a name="bin_paths"></a>`bin_paths`

Data type: `Array[Stdlib::Absolutepath]`

Paths to add to PATH

Default value: `['/usr/lpp/mmfs/bin']`

## Defined types

### <a name="gpfsclientrkm"></a>`gpfs::client::rkm`

Manage GPFS client ISKLM configuration

#### Parameters

The following parameters are available in the `gpfs::client::rkm` defined type:

* [`rkm_id`](#rkm_id)
* [`type`](#type)
* [`kmip_server_uris`](#kmip_server_uris)
* [`key_store`](#key_store)
* [`key_store_source`](#key_store_source)
* [`passphrase`](#passphrase)
* [`client_cert_label`](#client_cert_label)
* [`tenant_name`](#tenant_name)
* [`connection_timeout`](#connection_timeout)
* [`connection_attempts`](#connection_attempts)
* [`retry_sleep`](#retry_sleep)
* [`order`](#order)

##### <a name="rkm_id"></a>`rkm_id`

Data type: `String[1]`



Default value: `$name`

##### <a name="type"></a>`type`

Data type: `String[1]`



Default value: `'ISKLM'`

##### <a name="kmip_server_uris"></a>`kmip_server_uris`

Data type: `Array`



Default value: `[]`

##### <a name="key_store"></a>`key_store`

Data type: `Stdlib::Absolutepath`



Default value: `'/var/mmfs/etc/RKMcerts/ISKLM.proj2'`

##### <a name="key_store_source"></a>`key_store_source`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="passphrase"></a>`passphrase`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="client_cert_label"></a>`client_cert_label`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="tenant_name"></a>`tenant_name`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="connection_timeout"></a>`connection_timeout`

Data type: `String[1]`



Default value: `'5'`

##### <a name="connection_attempts"></a>`connection_attempts`

Data type: `String[1]`



Default value: `'3'`

##### <a name="retry_sleep"></a>`retry_sleep`

Data type: `String[1]`



Default value: `'50000'`

##### <a name="order"></a>`order`

Data type: `String[1]`



Default value: `'10'`

## Resource types

### <a name="gpfs_config"></a>`gpfs_config`

GPFS config

#### Parameters

The following parameters are available in the `gpfs_config` type.

* [`filesystems`](#filesystems)
* [`name`](#name)

##### <a name="filesystems"></a>`filesystems`

Filesystems to manage

##### <a name="name"></a>`name`

namevar

GPFS config

### <a name="gpfs_fileset"></a>`gpfs_fileset`

Manage a GPFS fileset

#### Examples

##### Create `test` GPFS fileset

```puppet
gpfs_fileset { 'test':
  filesystem      => 'project',
  path            => '/gpfs/project/test',
  owner           => 'nobody:wheel',
  permissions     => '1770',
  inode_space     => 'new',
  max_num_inodes  => 1000000,
  alloc_inodes    => 1000000,
}
```

#### Properties

The following properties are available in the `gpfs_fileset` type.

##### `alloc_inodes`

Allocated inodes for fileset.

##### `ensure`

Valid values: `present`, `absent`, `unlinked`

The state of the fileset

Default value: `present`

##### `max_num_inodes`

Max number of inodes for fileset.

##### `owner`

Owner of GPFS fileset: user:group

##### `path`

The GPFS fileset path.

##### `permissions`

Permissions of fileset.

#### Parameters

The following parameters are available in the `gpfs_fileset` type.

* [`afm_attributes`](#afm_attributes)
* [`enforce_permissions`](#enforce_permissions)
* [`fileset`](#fileset)
* [`filesystem`](#filesystem)
* [`inode_space`](#inode_space)
* [`inode_tolerance`](#inode_tolerance)
* [`name`](#name)
* [`provider`](#provider)

##### <a name="afm_attributes"></a>`afm_attributes`

AFM attributes

##### <a name="enforce_permissions"></a>`enforce_permissions`

Valid values: ``true``, ``false``

Enforce POSIX permissions after creation

Default value: ``false``

##### <a name="fileset"></a>`fileset`

The GPFS fileset name.

##### <a name="filesystem"></a>`filesystem`

The GPFS filesystem name.

##### <a name="inode_space"></a>`inode_space`

inodeSpace of fileset.

Default value: `new`

##### <a name="inode_tolerance"></a>`inode_tolerance`

Number of inodes to allow GPFS to adjust max or allocated inodes without triggering a Puppet change

Default value: `32`

##### <a name="name"></a>`name`

namevar

The default namevar.

##### <a name="provider"></a>`provider`

The specific backend to use for this `gpfs_fileset` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="gpfs_fileset_quota"></a>`gpfs_fileset_quota`

**Autorequires**:
  * `gpfs_fileset` - Puppet will autorequire the `gpfs_fileset` resource defined in `fileset` property.

#### Examples

##### Add fileset quota to `test` fileset.

```puppet
gpfs_fileset_quota { 'test':
  filesystem => 'project',
  block_soft_limit  => '5T',
  block_hard_limit  => '5T',
  files_soft_limit  => 1000000,
  files_hard_limit  => 1000000,
}
```

#### Properties

The following properties are available in the `gpfs_fileset_quota` type.

##### `block_hard_limit`

blockHardLimit of quota

##### `block_soft_limit`

blockSoftLimit of quota

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `files_hard_limit`

filesHardLimit of quota

##### `files_soft_limit`

filesSoftLimit of quota

#### Parameters

The following parameters are available in the `gpfs_fileset_quota` type.

* [`fileset`](#fileset)
* [`filesystem`](#filesystem)
* [`name`](#name)
* [`object_name`](#object_name)
* [`provider`](#provider)
* [`type`](#type)

##### <a name="fileset"></a>`fileset`

The GPFS fileset name.

##### <a name="filesystem"></a>`filesystem`

The GPFS filesystem name.

##### <a name="name"></a>`name`

namevar

The default namevar

##### <a name="object_name"></a>`object_name`

The GPFS quota object name

##### <a name="provider"></a>`provider`

The specific backend to use for this `gpfs_fileset_quota` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="type"></a>`type`

Quota type

Default value: `fileset`

### <a name="scalemgmt_config"></a>`scalemgmt_config`

scalemgmt config

#### Parameters

The following parameters are available in the `scalemgmt_config` type.

* [`api_password`](#api_password)
* [`api_user`](#api_user)
* [`base_url`](#base_url)
* [`name`](#name)

##### <a name="api_password"></a>`api_password`

API password

Default value: `admin001`

##### <a name="api_user"></a>`api_user`

API user

Default value: `admin`

##### <a name="base_url"></a>`base_url`

Base URL of GPFS API

Default value: `https://localhost:443/scalemgmt/`

##### <a name="name"></a>`name`

namevar

scalemgmt config

### <a name="scalemgmt_conn_validator"></a>`scalemgmt_conn_validator`

Verify that a connection can be successfully established between a node
and the scalemgmt server.  Its primary use is as a precondition to
prevent configuration changes from being applied if the scalemgmt
server cannot be reached, but it could potentially be used for other
purposes such as monitoring.

#### Properties

The following properties are available in the `scalemgmt_conn_validator` type.

##### `ensure`

Valid values: `present`, `absent`

Ensure

Default value: `present`

#### Parameters

The following parameters are available in the `scalemgmt_conn_validator` type.

* [`api_password`](#api_password)
* [`api_user`](#api_user)
* [`name`](#name)
* [`provider`](#provider)
* [`scalemgmt_port`](#scalemgmt_port)
* [`scalemgmt_server`](#scalemgmt_server)
* [`test_url`](#test_url)
* [`timeout`](#timeout)

##### <a name="api_password"></a>`api_password`

API password

Default value: `admin001`

##### <a name="api_user"></a>`api_user`

API user name

Default value: `admin`

##### <a name="name"></a>`name`

namevar

An arbitrary name used as the identity of the resource.

##### <a name="provider"></a>`provider`

The specific backend to use for this `scalemgmt_conn_validator` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

##### <a name="scalemgmt_port"></a>`scalemgmt_port`

The port that the scalemgmt server should be listening on.

Default value: `443`

##### <a name="scalemgmt_server"></a>`scalemgmt_server`

The DNS name or IP address of the server where scalemgmt should be running.

Default value: `localhost`

##### <a name="test_url"></a>`test_url`

URL to use for testing if the scalemgmt API is up

Default value: `/scalemgmt/v2/info`

##### <a name="timeout"></a>`timeout`

The max number of seconds that the validator should wait before giving up and deciding that scalemgmt is not running;
defaults to 30 seconds.

Default value: `30`

